.. _userstory:

User stories
************

Planning based research
=======================

Andrew plans his research first and then executes the tasks.

- In the project view of PASTA-ELN, he enters the steps to reach his research goal and breaks the steps down into a further series of sub-steps, depending on the necessary level of granularity. For each task item added to the project view, a folder is automatically created inside the root project folder. As such, the created project hierarchy in PASTA-ELN GUI is reflected in the folder hierarchy.
- When executing tasks, Andrew collects data and metadata, which is then assigned to a corresponding task in his project. To manage data files within PASTA-ELN, they have to be added to the project by moving/copying to the respective task folder, followed by scanning the hierarchy in the project view. The metadata of the files, i.e., vendor metadata, is obtained automatically by the extractor programs during the scanning process.
- To add metadata that describes samples or instruments used to complete certain tasks, e.g, perform measurements, Andrew can link the previously created sample or instrument items to the measurement entries in the project view. He also uses the "Procedures" category to organize the experimental workflows and link those to the executed tasks or subtasks. Metadata that needs to be manually entered, e.g., Andrew's notes on results quality or experimental process, can be added in the comment section either of a task itself or the attached data file.

This approach creates a planning-based project structure and allows Andrew to keep track of the steps required to reach his research goal and the corresponding data entries.

Importing previous data
=======================

Brenda has lots of data from her previous research in different folders and wants to integrate that data conveniently.

- Since the data is already structured according to Brenda's preferences, she might need to adapt the ontology and metadata definitions of the PASTA-ELN project to her research. The required data and metadata types can be entered in the "Questionnaire editor" in the settings.
- Before integrating the existing data into PASTA-ELN, Brenda needs to create a project and then copy or move her folders and data files into the project directory. The extractors for the corresponding file extensions are created to ensure that the required metadata is retrieved from the data files. Afterwards, when the project hierarchy is scanned, her data and metadata are automatically added to the project, keeping the previously existing folder structure.
- After the entire data collection has been added to the project, Brenda can manually fill in additional metadata, comments, and links to other items, e.g., samples or procedures.

This workflow demonstrates how the adaptability of PASTA-ELN can be used to integrate and manage large amounts of data while a low amount of input is required from the user itself.

Recording meeting notes
=======================

Claire goes to many conferences and meetings and wants to structure her notes.

- Claire can create an arbitrary structure within a project and record her notes as comments to each item in Markdown format. The comments are then formatted and immediately displayed for each item created in the project view, providing a clear overview of the notes.
- The notes in comments can be linked to the data files, as those can be attached by copying or moving to the respective folder.

The Markdown comment tool is versatile and allows one to create and structure notes easily.